pub struct PdfPageJustified {
pub lines: Vec<String>,
pub head_partial: Option<PartialParagraph>,
pub tail_partial: Option<PartialParagraph>,
}Expand description
Justified output for a single PDF page, augmented with the raw text of any partial paragraphs that may continue onto a neighbouring page.
Fields
lines: Vec<String>head_partial: Option<PartialParagraph>tail_partial: Option<PartialParagraph>Auto Trait Implementations
impl Freeze for PdfPageJustified
impl RefUnwindSafe for PdfPageJustified
impl Send for PdfPageJustified
impl Sync for PdfPageJustified
impl Unpin for PdfPageJustified
impl UnsafeUnpin for PdfPageJustified
impl UnwindSafe for PdfPageJustified